# Copyright (c) 2007 Red Hat
# Written by Jakub Hrozek. Much of this code was taken and adapted for sectool
# from the 'func' project see https://fedorahosted.org/func, file func/logger.py
# -*- coding: UTF8 -*-

from i18n import _
import scheduler

import logging

# from the comments in http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/66531
class Singleton(object):
    def __new__(type, *args, **kwargs):
        if not '_the_instance' in type.__dict__:
            type._the_instance = object.__new__(type, *args, **kwargs)
        return type._the_instance

class Logger(Singleton):
    _no_handlers = True

    def __init__(self, log_path='/var/log/sectool.log'):
        self.logger  = logging.getLogger('sectool')
        if self._no_handlers:
            self._set_handlers(log_path)

    def _set_handlers(self, log_path):
        handler = logging.FileHandler(log_path, 'a')
        formatter = logging.Formatter('%(asctime)s - %(message)s', '%b %d %H:%M:%S')
        handler.setFormatter(formatter)
        self.logger.addHandler(handler)
        self._no_handlers = False

    def log_message(self, test_name, msg_id, severity, message):
        # we'd like to log only errors and warnings
        if severity > scheduler.OutputItem.t_warning:
            return

        str_labels = { scheduler.OutputItem.t_error : _("Error"),
                       scheduler.OutputItem.t_warning : _("Warning"),
                       scheduler.OutputItem.t_failure : _("Failure") }
        log_level_map = { scheduler.OutputItem.t_error : logging.ERROR,
                          scheduler.OutputItem.t_warning : logging.WARNING }

        self.logger.log(log_level_map[severity], 
                        "%s %s %s %s" % (test_name, msg_id, str_labels[severity], message))
